@@ -1,9 +1,9 @@
 from typing import List, Optional
 
 import attr
-
-from secoda_common.models.user import User
 from marshmallow_annotations.ext.attrs import AttrsSchema
+from secoda_common.models.tag import Tag
+from secoda_common.models.user import User
 
 
 @attr.s(auto_attribs=True, kw_only=True)
@@ -18,18 +18,6 @@ class ReaderSchema(AttrsSchema):
         register_as_scheme = True
 
 
-@attr.s(auto_attribs=True, kw_only=True)
-class Tag:
-    tag_type: str
-    tag_name: str
-
-
-class TagSchema(AttrsSchema):
-    class Meta:
-        target = Tag
-        register_as_scheme = True
-
-
 @attr.s(auto_attribs=True, kw_only=True)
 class Badge:
     badge_name: str = attr.ib()
@@ -70,6 +58,20 @@ class StatSchema(AttrsSchema):
         register_as_scheme = True
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class ColumnReference:
+    key: Optional[str] = None
+    name: str
+    table: str
+    is_pk: bool = False
+
+
+class ColumnReferenceSchema(AttrsSchema):
+    class Meta:
+        target = ColumnReference
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Column:
     name: str
@@ -80,6 +82,8 @@ class Column:
     stats: List[Stat] = []
     badges: Optional[List[Badge]] = []
     tags: Optional[List[Tag]] = []
+    is_pk: Optional[bool] = None
+    column_reference: Optional[ColumnReference] = None
 
 
 class ColumnSchema(AttrsSchema):
